@@ -251,7 +251,7 @@
 #define INSTALL_SCRIPTDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLDATADIR "/usr/local/mysql/data"
 #define INSTALL_MYSQLKEYRINGDIR "/usr/local/mysql/keyring"
-#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.11-4/plugin/scalability_metrics/tests;/build/percona-server/src/percona-server-5.7.11-4/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.11-4/plugin/audit_log/tests"
+#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.11-4/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.11-4/plugin/scalability_metrics/tests;/build/percona-server/src/percona-server-5.7.11-4/plugin/query_response_time/tests"
 #define INSTALL_INFODIR "/usr/local/mysql/share/mysql/docs"
 #define INSTALL_MYSQLTESTDIR "/usr/local/mysql/mysql-test"
 #define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/mysql"
